@@ -24,12 +24,12 @@
 # \value{
 #   Returns nothing.
 # }
-# 
-# @author
+#
+# @author "HB"
 #
 # @keyword IO
 # @keyword internal
-#*/########################################################################### 
+#*/###########################################################################
 setMethodS3("plotTracks", "CBS", function(x, scatter=TRUE, pch=20, col="gray", meanCol="purple", cex=1, grid=FALSE, Clim="auto", xScale=1e-6, Clab="auto", ..., byIndex=FALSE, mar=NULL, add=FALSE) {
   # To please R CMD check
   fit <- x;
@@ -37,9 +37,9 @@ setMethodS3("plotTracks", "CBS", function(x, scatter=TRUE, pch=20, col="gray", m
 
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   # Validate arguments
-  # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - 
+  # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   # Argument 'Clim':
-  if (identical(Clim, "auto")) { 
+  if (identical(Clim, "auto")) {
     signalType <- getSignalType(fit);
     Clim <- switch(signalType,
       "log2ratio" = c(-3,3),
@@ -48,7 +48,7 @@ setMethodS3("plotTracks", "CBS", function(x, scatter=TRUE, pch=20, col="gray", m
     );
   }
 
-  if (identical(Clab, "auto")) { 
+  if (identical(Clab, "auto")) {
     signalType <- getSignalType(fit);
     Clab <- switch(signalType,
       "log2ratio" = "log2 CN ratio",
@@ -110,7 +110,7 @@ setMethodS3("plotTracks", "CBS", function(x, scatter=TRUE, pch=20, col="gray", m
   }
   drawLevels(fit, col=meanCol, xScale=xScale);
 
-  invisible();  
+  invisible();
 }) # plotTracks()
 
 
@@ -120,8 +120,13 @@ setMethodS3("plot", "CBS", function(x, ...) {
 
 
 setMethodS3("drawLevels", "CBS", function(fit, col="purple", xScale=1e-6, ...) {
+  # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+  # Tile chromosomes
+  # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+  fitT <- tileChromosomes(fit);
+
   # Get segmentation results
-  segs <- as.data.frame(fit);
+  segs <- as.data.frame(fitT);
 
   # Extract subset of segments
   fields <- c("start", "end", "mean");
@@ -147,7 +152,7 @@ setMethodS3("highlightCalls", "CBS", function(fit, pch=20, callCols=c(loss="red"
   nbrOfCalls <- length(callFields);
 
   # Nothing todo?
-  if (nbrOfCalls == 0) {
+  if (nbrOfCalls == 0L) {
     return();
   }
 
@@ -156,7 +161,6 @@ setMethodS3("highlightCalls", "CBS", function(fit, pch=20, callCols=c(loss="red"
   # Tile chromosomes
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   fitT <- tileChromosomes(fit);
-  verbose && str(verbose, fitT);
 
 
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -232,7 +236,6 @@ setMethodS3("highlightLocusCalls", "CBS", function(fit, callPchs=c(negOutlier=25
   # Tile chromosomes
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   fitT <- tileChromosomes(fit);
-  verbose && str(verbose, fitT);
 
 
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -271,216 +274,13 @@ setMethodS3("highlightLocusCalls", "CBS", function(fit, callPchs=c(negOutlier=25
 
 
 
-setMethodS3("tileChromosomes", "CBS", function(fit, ..., verbose=FALSE) {
-  # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-  # Validate arguments
-  # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - 
-  # Argument 'verbose':
-  verbose <- Arguments$getVerbose(verbose);
-  if (verbose) {
-    pushState(verbose);
-    on.exit(popState(verbose));
-  }
-
-
-  verbose && enter(verbose, "Tiling chromosomes");
-
-  # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-  # Extract data and segments
-  # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-  data <- getLocusData(fit);
-  segs <- getSegments(fit);
-  knownSegments <- fit$params$knownSegments;
-
-  # Identify all chromosome
-  chromosomes <- getChromosomes(fit);
-  
-  # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-  # Additional chromosome annotations
-  # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-  chrStats <- getChromosomeRanges(fit);
-
-  # Build an "empty" row with start == 1.
-  chrStatsKK <- chrStats[1,,drop=FALSE][NA,,drop=FALSE];
-  chrStatsKK[,"start"] <- 1L;
-
-  # Append empty row
-  chrStats <- rbind(chrStats, chrStatsKK);
-
-  # Offset (start,stop)
-  chrOffsets <- getChromosomeOffsets(fit, ...);
-  chrStats[,"start"] <- chrStats[,"start"] + chrOffsets;
-  chrStats[,"end"] <- chrStats[,"end"] + chrOffsets;
-
-
-  # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-  # Offset...
-  # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-  segFields <- grep("(start|end)$", colnames(segs), value=TRUE);
-  for (kk in seq(along=chromosomes)) {
-    chromosome <- chromosomes[kk];
-    chrTag <- sprintf("Chr%02d", chromosome);
-    verbose && enter(verbose, sprintf("Chromosome #%d ('%s') of %d", 
-                                         kk, chrTag, length(chromosomes)));
-
-    # Get offset for this chromosome
-    offset <- chrOffsets[kk];
-    verbose && cat(verbose, "Offset: ", offset);
-
-    # Offset data
-    idxs <- which(data$chromosome == chromosome);
-    data$x[idxs] <- offset + data$x[idxs];
-
-    # Offset segmentation
-    idxs <- which(segs$chromosome == chromosome);
-    segs[idxs,segFields] <- offset + segs[idxs,segFields];
-
-    # Offset known segments
-    idxs <- which(knownSegments$chromosome == chromosome);
-    knownSegments[idxs,c("start", "end")] <- offset + knownSegments[idxs,c("start", "end")];
-
-    verbose && exit(verbose);
-  } # for (kk ...)
-
-
-  # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-  # Update results
-  # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-  fitT <- fit;
-  fitT$data <- data;
-  fitT$output <- segs;
-  fitT$chromosomeStats <- chrStats;
-  fitT$params$knownSegments <- knownSegments;
-  fitT$params$chrOffsets <- chrOffsets;
-
-
-  # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-  # Sanity checks
-  # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-  segs <- getSegments(fit);
-  segsT <- getSegments(fitT);
-  segs <- segs[,!is.element(colnames(segs), c("start", "end"))];
-  segsT <- segsT[,!is.element(colnames(segsT), c("start", "end"))];
-  stopifnot(all.equal(segsT, segs));
-
-  data <- getLocusData(fit);
-  dataT <- getLocusData(fitT);
-  data <- segs[,!is.element(colnames(data), c("x"))];
-  dataT <- segsT[,!is.element(colnames(dataT), c("x"))];
-  stopifnot(all.equal(dataT, data));
-
-  stopifnot(nbrOfLoci(fitT) == nbrOfLoci(fit));
-  stopifnot(nbrOfSegments(fitT) == nbrOfSegments(fit));
-
-  verbose && exit(verbose);
-
-  fitT;
-}, protected=TRUE) # tileChromosomes()
-
-
-
-setMethodS3("plotTracksManyChromosomes", "CBS", function(x, scatter=TRUE, pch=20, col="gray", meanCol="purple", Clim=c(0,6), xScale=1e-6, xlab="Genomic position", Clab="TCN", ..., subset=NULL, byIndex=FALSE, add=FALSE, onBegin=NULL, onEnd=NULL, mar=NULL, verbose=FALSE) {
-  # To please R CMD check
-  fit <- x;
- 
-  # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-  # Validate arguments
-  # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - 
-  # Argument 'fit':
-
-  # Argument 'xScale':
-  xScale <- Arguments$getNumeric(xScale, range=c(0,Inf));
-
-  # Argument 'subset':
-  if (!is.null(subset)) {
-    subset <- Arguments$getDouble(subset, range=c(0,1));
-  }
-
-  # Argument 'verbose':
-  verbose <- Arguments$getVerbose(verbose);
-  if (verbose) {
-    pushState(verbose);
-    on.exit(popState(verbose));
-  }
-
-
-  # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-  # Tile chromosomes
-  # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-  fitT <- tileChromosomes(fit);
-  verbose && str(verbose, fitT);
-  # Sanity check
-  stopifnot(!is.null(fitT$chromosomeStats));
-
-  # Extract the input data
-  data <- getLocusData(fitT);
-  if (is.null(data)) {
-    throw("Cannot plot segmentation results. No input data available.");
-  }
-
-  # Subset of the loci?
-  if (!is.null(subset) && subset < 1) {
-    n <- nrow(data);
-    keep <- sample(n, size=subset*n);
-    data <- data[keep,];
-  }
-
-  # To please R CMD check
-  CT <- y <- muN <- betaT <- betaN <- betaTN <- NULL;
-  rm(CT, muN, betaT, betaN, betaTN);
-  attachLocally(data);
-  x <- xScale * x;
-  chrStats <- fitT$chromosomeStats;
-  chrStats <- chrStats[-nrow(chrStats),,drop=FALSE];
-  chrRanges <- as.matrix(chrStats[,c("start","end")]);
-  vs <- xScale * chrRanges;
-  mids <- (vs[,1]+vs[,2])/2;
-  CT <- y;
-
-  nbrOfLoci <- length(x);
-  chromosomes <- getChromosomes(fitT);
-  chrLabels <- sprintf("%02d", chromosomes);
-
-  if (byIndex) {
-    xs <- seq(along=x);
-  } else {
-    xs <- x;
-  }
-
-  if (!add && !is.null(mar)) {
-    par(mar=mar);
-  }
-
-  gh <- fitT;
-  gh$xScale <- xScale;
-
-  xlim <- xScale*range(chrRanges, na.rm=TRUE);
-
-  pchT <- if (scatter) { pch } else { NA };
-
-  plot(NA, xlim=xlim, ylim=Clim, xlab=xlab, ylab=Clab, axes=FALSE);
-  if (!is.null(onBegin)) onBegin(gh=gh);
-  points(xs, CT, pch=pchT, col=col, ...);
-  side <- rep(c(1,3), length.out=length(chrLabels));
-  mtext(text=chrLabels, side=side, at=mids, line=0.1, cex=0.7*par("cex"));
-  abline(v=vs, lty=3);
-  axis(side=2); 
-  box();
-  drawLevels(fitT, col=meanCol, xScale=xScale, byIndex=byIndex);
-  if (!is.null(onEnd)) onEnd(gh=gh);
-
-  invisible(gh);
-}, private=TRUE) # plotTracksManyChromosomes()
-
-
-
 setMethodS3("drawChromosomes", "CBS", function(x, lty=3, xScale=1e-6, ..., byIndex=FALSE, verbose=FALSE) {
   # To please R CMD check
   fit <- x;
- 
+
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   # Validate arguments
-  # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - 
+  # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   # Argument 'fit':
 
   # Argument 'xScale':
@@ -497,7 +297,6 @@ setMethodS3("drawChromosomes", "CBS", function(x, lty=3, xScale=1e-6, ..., byInd
   # Tile chromosomes
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   fitT <- tileChromosomes(fit);
-  verbose && str(verbose, fitT);
   # Sanity check
   stopifnot(!is.null(fitT$chromosomeStats));
 
@@ -516,9 +315,9 @@ setMethodS3("drawChromosomes", "CBS", function(x, lty=3, xScale=1e-6, ..., byInd
 
 
 setMethodS3("drawCentromeres", "CBS", function(fit, genomeData, what=c("start", "end"), xScale=1e-6, col="gray", lty=3, ..., byIndex=FALSE) {
-  # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - 
+  # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   # Validate arguments
-  # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - 
+  # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   # Argument 'genomeData':
   stopifnot(inherits(genomeData, "data.frame"));
   stopifnot(is.element("chromosome", colnames(genomeData)));
@@ -533,7 +332,6 @@ setMethodS3("drawCentromeres", "CBS", function(fit, genomeData, what=c("start",
   # Tile chromosomes
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   fitT <- tileChromosomes(fit);
-  verbose && str(verbose, fitT);
   # Sanity check
   stopifnot(!is.null(fitT$chromosomeStats));
 
@@ -612,25 +410,10 @@ setMethodS3("highlightArmCalls", "CBS", function(fit, genomeData, minFraction=0.
 
 
 
-
-setMethodS3("drawChangePoints", "CBS", function(fit, labels=FALSE, cex=0.5, col="#666666", xScale=1e-6, side=3, line=-1, xpd=TRUE, ..., verbose=FALSE) {
-  segs <- getSegments(fit, splitters=FALSE);
-  xStarts <- segs[,"start"];
-  xEnds <- segs[,"end"];
-
-  xs <- sort(unique(c(xStarts, xEnds)));
-  abline(v=xScale*xs, lty=1, col=col);
-
-  if (labels) {
-    xMids <- xScale * (xEnds + xStarts) / 2;
-    labels <- rownames(segs);
-    mtext(side=side, at=xMids, labels, line=line, cex=cex, col=col, xpd=xpd, ...);
-  }
-}, protected=TRUE)
-
-
 ############################################################################
 # HISTORY:
+# 2013-04-18
+# o Now drawLevels() also works for multiple chromosomes.
 # 2011-12-06
 # o Now plotTracks() for CBS always returns an invisible object.
 # 2011-12-03
@@ -657,4 +440,4 @@ setMethodS3("drawChangePoints", "CBS", function(fit, labels=FALSE, cex=0.5, col=
 #   the loci, and hence generated corrupt/missing values while tiling.
 # 2010-11-19
 # o Created from PairedPSCBS.R.
-############################################################################ 
+############################################################################
