@@ -21,7 +21,7 @@
 #  @allmethods "public"
 # }
 # 
-# @author
+# @author "HB"
 #
 # \seealso{
 #   The @see "segmentByPairedPSCBS" method returns an object of this class.
@@ -37,8 +37,50 @@ setConstructorS3("PairedPSCBS", function(fit=list(), ...) {
 })
 
 
+setMethodS3("getLocusData", "PairedPSCBS", function(fit, ..., fields=c("asis", "full")) {
+  # Argument 'fields':
+  fields <- match.arg(fields);
 
-setMethodS3("updateMeans", "PairedPSCBS", function(fit, from=c("loci", "segments"), adjustFor=NULL, ..., verbose=FALSE) {
+
+  data <- NextMethod("getLocusData", fields="asis");
+
+
+  if (fields == "full") {
+    names <- colnames(data);
+
+    # Genotype calls
+    if (!is.element("muN", names)) {
+      require("aroma.light") || throw("Package not loaded: aroma.light");
+      data$muN <- callNaiveGenotypes(data$betaN);
+    }
+    data$isHet <- (data$muN == 1/2);
+
+    data$rho <- 2*abs(data$betaT-1/2);
+    data$c1 <- 1/2*(1-data$rho)*data$CT;
+    data$c2 <- data$CT - data$c1;
+
+    # TumorBoost BAFs
+    if (!is.element("betaTN", names)) {
+      require("aroma.light") || throw("Package not loaded: aroma.light");
+      data$betaTN <- normalizeTumorBoost(betaN=data$betaN, betaT=data$betaT, muN=data$muN);
+    }
+    data$rhoN <- 2*abs(data$betaTN-1/2);
+    data$c1N <- 1/2*(1-data$rhoN)*data$CT;
+    data$c2N <- data$CT - data$c1N;
+
+    data$isSNP <- (!is.na(data$betaT) | !is.na(data$betaN));
+    data$type <- ifelse(data$isSNP, "SNP", "non-polymorphic locus");
+
+    # Labels
+    data$muNx <- c("AA", "AB", "BB")[2*data$muN + 1L];
+    data$isHetx <- c("AA|BB", "AB")[data$isHet + 1L];
+  }
+
+  data;
+}, protected=TRUE) # getLocusData()
+
+
+setMethodS3("updateMeans", "PairedPSCBS", function(fit, from=c("loci", "segments"), adjustFor=NULL, ..., avgTCN=c("mean", "median"), avgDH=c("mean", "median"), verbose=FALSE) {
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   # Validate arguments
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - 
@@ -53,6 +95,10 @@ setMethodS3("updateMeans", "PairedPSCBS", function(fit, from=c("loci", "segments
     adjustFor <- match.arg(adjustFor, choices=knownValues, several.ok=TRUE);
   }
 
+  # Argument 'avgTCN' & 'avgDH':
+  avgTCN <- match.arg(avgTCN);
+  avgDH <- match.arg(avgDH);
+
   # Argument 'verbose':
   verbose <- Arguments$getVerbose(verbose);
   if (verbose) {
@@ -65,6 +111,15 @@ setMethodS3("updateMeans", "PairedPSCBS", function(fit, from=c("loci", "segments
   verbose && print(verbose, adjustFor);
 
 
+  # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - 
+  # Setting up averaging functions
+  # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - 
+  avgList <- list(
+    tcn = get(avgTCN, mode="function"),
+    dh = get(avgDH, mode="function")
+  );
+
+
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - 
   # Extract the segmentation results
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - 
@@ -118,6 +173,8 @@ setMethodS3("updateMeans", "PairedPSCBS", function(fit, from=c("loci", "segments
       chrTag <- sprintf("chr%02d", chr);
   
       for (what in c("tcn", "dh")) {
+        avgFUN <- avgList[[what]];
+
         keys <- paste(what, c("Start", "End"), sep="");
         xStart <- seg[[keys[1]]];
         xEnd <- seg[[keys[2]]];
@@ -142,7 +199,7 @@ setMethodS3("updateMeans", "PairedPSCBS", function(fit, from=c("loci", "segments
         units <- units[keep];
   
         # (d) Update mean
-        gamma <- mean(value[units]);
+        gamma <- avgFUN(value[units]);
   
         # Sanity check
         stopifnot(length(units) == 0 || !is.na(gamma));
@@ -213,6 +270,7 @@ setMethodS3("updateMeans", "PairedPSCBS", function(fit, from=c("loci", "segments
   # Return results
   res <- fit;
   res$output <- segs;
+  res <- setMeanEstimators(res, tcn=avgTCN, dh=avgDH);
 
   verbose && exit(verbose);
 
@@ -221,7 +279,6 @@ setMethodS3("updateMeans", "PairedPSCBS", function(fit, from=c("loci", "segments
 
 
 
-
 setMethodS3("resegment", "PairedPSCBS", function(fit, ..., verbose=FALSE) {
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   # Validate arguments
@@ -306,6 +363,8 @@ setMethodS3("resegment", "PairedPSCBS", function(fit, ..., verbose=FALSE) {
 
 ##############################################################################
 # HISTORY
+# 2013-03-08
+# o Added getLocusData() for PairedPSCBS.
 # 2012-04-21
 # o CLEANUP: Removed unused objects in updateMeans().
 # o CLEANUP: Moved getSegmentSizes() from PairedPSCBS to PSCBS.
